@@ -2,10 +2,9 @@
 get_dimension_values = function(dimension, col_name ,name = FALSE){
 
   dir_creation_fail = try(create_insee_folder(), silent = TRUE)
+  insee_local_dir = file.path(rappdirs::user_data_dir(), "R", "insee", "insee")
 
-  if(!"try-error" %in% class(dir_creation_fail)){
-    insee_local_dir = file.path(rappdirs::user_data_dir(), "R", "insee", "insee")
-  }else{
+  if(("try-error" %in% class(dir_creation_fail))|(!file.exists(insee_local_dir))){
     insee_local_dir = tempdir()
   }
 
