@@ -12,7 +12,12 @@
 #' all the data is returned, and column names refer directly to data dimensions
 #' @param update It is FALSE by default, if it is set to TRUE, it triggers the metadata update. This update is automatically triggered once every 6 months.
 #' @examples
-#' \donttest{idbank_list = get_idbank_list()}
+#' \donttest{
+#' # download datasets list
+#' dt = get_dataset_list()
+#' # use a dataset name to retrieve the series key list related to the dataset
+#' idbank_list = get_idbank_list('CNT-2014-PIB-EQB-RF')
+#' }
 #' @return a tibble the idbank dataset
 #' @export
 get_idbank_list = function(
@@ -168,10 +173,14 @@ get_idbank_list = function(
       idbank_list = try(download_idbank_list(), silent = TRUE)
 
       if("try-error" %in% class(idbank_list)){
-
-        idbank_list = clean_table(
-          dplyr::filter(.data = idbank_list_internal, .data$nomflow %in% dataset)
-        )
+        
+        if(!is.null(dataset)){
+          idbank_list = clean_table(
+            dplyr::filter(.data = idbank_list_internal, .data$nomflow %in% dataset)
+          )
+        }else{
+          idbank_list = idbank_list_internal
+        }
 
         msg1 = "\n\nIdbank list download failed"
         msg2 = "\nPackage's internal data has been used instead"
